package com.unis.vis.controller;

import com.unis.vis.model.*;
import com.unis.vis.controller.vo.MaterialReserveSituationVO;
import com.unis.vis.model.InboundMaterialInfo;
import com.unis.vis.model.OutboundMaterialInfo;
import com.unis.vis.model.SysDept;
import com.unis.vis.model.SysTreeDict;
import com.unis.vis.service.InboundMaterialInfoService;
import com.unis.vis.service.OutboundMaterialInfoService;
import com.unis.vis.service.SysDeptService;
import com.unis.vis.service.SysTreeDictService;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * @author qingsong.han
 * @description: 可视化接口
 * @create 2024-03-01 20:01
 */
@RestController
@RequestMapping("/vis")
public class VisController {
    @Resource
    private SysTreeDictService sysTreeDictService;

    @Resource
    private InboundMaterialInfoService inboundMaterialInfoService;

    @Resource
    private OutboundMaterialInfoService outboundMaterialInfoService;

    @Resource
    private SysDeptService sysDeptService;


    @GetMapping("/test")
     public List<SysTreeDict> test() {
        List<SysTreeDict> list = sysTreeDictService.list();
        return list;
    }

    /*应用物资大类*/
    @GetMapping("/getEmergencySuppliesCategory")
    public List<InboundMaterialInfo> getEmergencySuppliesCategory() {
        List<InboundMaterialInfo> list = inboundMaterialInfoService.getEmergencySuppliesCategory();
        return list;
    }

    /**
     * 物资入库情况
     * @return
     */
    @GetMapping("/getInventoryReceiptStatus")
    public List<InboundMaterialInfo> getInventoryReceiptStatus() {
        List<InboundMaterialInfo> list = inboundMaterialInfoService.getInventoryReceiptStatus();
        return list;
    }

    /**
     * 物资出库情况
     * @return
     */
    @GetMapping("/getInventoryDispatchStatus")
    public List<OutboundMaterialInfo> getInventoryDispatchStatus() {
        List<OutboundMaterialInfo> list = outboundMaterialInfoService.getInventoryDispatchStatus();
        return list;
    }

    /*物资情况*/
    @GetMapping("/getMaterialSituation")
    public List<InboundMaterialInfo> getMaterialSituation() {
        List<InboundMaterialInfo> list = inboundMaterialInfoService.getMaterialSituation();
        return list;
    }

    /*物资调用情况*/
    /*调用：1 调出：2*/
    @GetMapping("/getMaterialCallSituation")
    public List<OutboundMaterialInfo> getMaterialCallSituation(@RequestParam("type") String type,
                                                               @RequestParam("action")Integer action) {

        List<OutboundMaterialInfo> list = outboundMaterialInfoService.getMaterialCallSituation(type,action);
        return list;
    }
    /*地图点位*/
    @GetMapping("/getMapPoint")
    public List<SysDept> getMapPoint() {
        List<SysDept> list = sysDeptService.getMapPoint();
        return list;
    }
    /**
     * 物资储备情况
     */
    @GetMapping("/get-material-situation")
    public Map<String,List<MaterialReserveSituationVO>> selectWarehouseForMaterialType(@RequestParam String warehouse) {
        return inboundMaterialInfoService.selectWarehouseForMaterialType(warehouse);
    }
    /**
     * 出入库记录
     * type: 1入库 2出库
     * @return
     */
    @GetMapping("/entry_exit_records")
    public List<OutAndInboundRecord> getEnterExitRecords(@RequestParam(value = "type", required = false) Integer type,
                                                         @RequestParam(value = "name", required = false) String name){
        return inboundMaterialInfoService.getEnterExitRecords(type,name);
    }

    /*损耗记录*/
    @GetMapping("/getLossRecord")
    public List<OutboundMaterialInfo> getLossRecord() {
        List<OutboundMaterialInfo> list = outboundMaterialInfoService.getLossRecord();
        return list;
    }
}
